==> easymaker-1.0.4-py3-none-any.whl: easymaker/training/training.py <==
import time
from datetime import timedelta
import easymaker
from easymaker.common import exceptions
from easymaker.common import utils
from easymaker.common.utils import status_code_utils
from easymaker.common import constants


class Training:
    _framework_name = None
    _framework_version = None

    def __init__(self):
        self.easymaker_api_sender = easymaker.easymaker_config.api_sender
        self.instance_list = self.easymaker_api_sender.get_instance_list()
        self.image_list = self.easymaker_api_sender.get_image_list()

    def run(self,
            experiment_id=None,
            training_name=None,
            training_description=None,
            train_image_name=None,
            train_instance_name=None,
            train_instance_count=None,
            data_storage_size=None,
            source_dir_uri=None,
            entry_point=None,
            hyperparameter_list=None,
            dataset_list=None,
            check_point_upload_uri=None,
            model_upload_uri=None,
            timeout_hours=720,
            tag_list=None,
            use_log=False,
            wait=True
            ):
        """
        Returns:
            training_id
        """
        # run training
        response = self.easymaker_api_sender.run_training(training_name=training_name,
                                                          training_description=training_description,
                                                          experiment_id=experiment_id,
                                                          image_id=utils.from_name_to_id(self.image_list, train_image_name),
                                                          flavor_id=utils.from_name_to_id(self.instance_list, train_instance_name),
                                                          instance_count=train_instance_count,
                                                          data_storage_size=data_storage_size,
                                                          source_dir_uri=source_dir_uri,
                                                          entry_point=entry_point,
                                                          hyperparameter_list=hyperparameter_list,
                                                          dataset_list=dataset_list,
                                                          check_point_upload_uri=check_point_upload_uri,
                                                          model_upload_uri=model_upload_uri,
                                                          training_type_code='NORMAL',
                                                          timeout_hours=timeout_hours,
                                                          tag_list=tag_list,
                                                          use_log=use_log)

        training_id = response['training']['trainingId']
        if wait:
            waiting_time_seconds = 0
            training_status = status_code_utils.replace_status_code(response['training']['trainingStatusCode'])
            while training_status != 'COMPLETE':
                print(f'[AI EasyMaker] Training create status : {training_status} ({timedelta(seconds=waiting_time_seconds)}) Please wait...')
                time.sleep(constants.EASYMAKER_API_WAIT_INTERVAL_SECONDS)
                waiting_time_seconds += constants.EASYMAKER_API_WAIT_INTERVAL_SECONDS
                training = self.easymaker_api_sender.get_training_by_id(training_id)
                training_status = status_code_utils.replace_status_code(training['training']['trainingStatusCode'])
                if 'FAILED_' in training_status or 'STOPPED' in training_status:
                    training['training']['trainingStatusCode'] = training_status
                    raise exceptions.EasyMakerError(training)
            print(f'[AI EasyMaker] Training create complete. Training Id : {training_id}')
        else:
            print(f'[AI EasyMaker] Training create request complete. Training Id : {training_id}')
        return training_id

==> easymaker-1.0.7-py3-none-any.whl: easymaker/training/training.py <==
import time
from datetime import timedelta
import easymaker
from easymaker.common import exceptions
from easymaker.common import utils
from easymaker.common.utils import status_code_utils
from easymaker.common import constants


class Training:
    _framework_name = None
    _framework_version = None

    def __init__(self):
        self.easymaker_api_sender = easymaker.easymaker_config.api_sender
        self.instance_list = self.easymaker_api_sender.get_instance_list()
        self.image_list = self.easymaker_api_sender.get_image_list()

    def run(self,
            experiment_id=None,
            training_name=None,
            training_description=None,
            train_image_name=None,
            train_instance_name=None,
            train_instance_count=None,
            data_storage_size=None,
            source_dir_uri=None,
            entry_point=None,
            hyperparameter_list=None,
            dataset_list=None,
            check_point_upload_uri=None,
            model_upload_uri=None,
            timeout_hours=720,
            tag_list=None,
            use_log=False,
            wait=True
            ):
        """
        Returns:
            training_id
        """
        # run training
        response = self.easymaker_api_sender.run_training(training_name=training_name,
                                                          training_description=training_description,
                                                          experiment_id=experiment_id,
                                                          image_id=utils.from_name_to_id(self.image_list, train_image_name),
                                                          flavor_id=utils.from_name_to_id(self.instance_list, train_instance_name),
                                                          instance_count=train_instance_count,
                                                          data_storage_size=data_storage_size,
                                                          source_dir_uri=source_dir_uri,
                                                          entry_point=entry_point,
                                                          hyperparameter_list=hyperparameter_list,
                                                          dataset_list=dataset_list,
                                                          check_point_upload_uri=check_point_upload_uri,
                                                          model_upload_uri=model_upload_uri,
                                                          training_type_code='NORMAL',
                                                          timeout_hours=timeout_hours,
                                                          tag_list=tag_list,
                                                          use_log=use_log)

        training_id = response['training']['trainingId']
        if wait:
            waiting_time_seconds = 0
            training_status = status_code_utils.replace_status_code(response['training']['trainingStatusCode'])
            while training_status != 'COMPLETE':
                print(f'[AI EasyMaker] Training create status : {training_status} ({timedelta(seconds=waiting_time_seconds)}) Please wait...')
                time.sleep(constants.EASYMAKER_API_WAIT_INTERVAL_SECONDS)
                waiting_time_seconds += constants.EASYMAKER_API_WAIT_INTERVAL_SECONDS
                training = self.easymaker_api_sender.get_training_by_id(training_id)
                training_status = status_code_utils.replace_status_code(training['training']['trainingStatusCode'])
                if '_FAILED' in training_status or 'FAIL_TRAIN' in training_status or 'STOPPED' in training_status:
                    training['training']['trainingStatusCode'] = training_status
                    raise exceptions.EasyMakerError(training)
            print(f'[AI EasyMaker] Training create complete. Training Id : {training_id}')
        else:
            print(f'[AI EasyMaker] Training create request complete. Training Id : {training_id}')
        return training_id
